@@ -534,7 +534,7 @@ HRESULT SnoreToasts::createToast()
     switch (setting) {
     case NotificationSetting_Enabled:
         ST_RETURN_ON_ERROR(setEventHandler(d->m_notification));
-        return d->m_notifier->Show(d->m_notification.Get());
+        break;
     case NotificationSetting_DisabledForApplication:
         error = L"DisabledForApplication";
         break;
@@ -548,24 +548,20 @@ HRESULT SnoreToasts::createToast()
         error = L"DisabledByManifest";
         break;
     }
-    std::wstringstream err;
-    err << L"Notifications are disabled\n"
-        << L"Reason: " << error << L"Please make sure that the app id is set correctly.\n"
-        << L"Command Line: " << GetCommandLineW();
-    tLog << err.str();
-    std::wcerr << err.str() << std::endl;
-    return S_FALSE;
+    if (!error.empty()) {
+        std::wstringstream err;
+        err << L"Notifications are disabled\n"
+            << L"Reason: " << error << L" Please make sure that the app id is set correctly.\n"
+            << L"Command Line: " << GetCommandLineW();
+        tLog << err.str();
+        std::wcerr << err.str() << std::endl;
+    }
+    return d->m_notifier->Show(d->m_notification.Get());
 }
 
 std::wstring SnoreToasts::version()
 {
-    static std::wstring ver = [] {
-        std::wstringstream st;
-        st << SNORETOAST_VERSION_MAJOR << L"." << SNORETOAST_VERSION_MINOR << L"."
-           << SNORETOAST_VERSION_PATCH;
-        return st.str();
-    }();
-    return ver;
+    return SNORETOAST_VERSION;
 }
 
 HRESULT SnoreToasts::backgroundCallback(const std::wstring &appUserModelId,
